==> gtk+-3.6.1.tar.xz: gtk+-3.6.1/gtk/a11y/gtkmenuaccessible.h <==
/* GAIL - The GNOME Accessibility Implementation Library
 * Copyright 2001 Sun Microsystems Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __GTK_MENU_ACCESSIBLE_H__
#define __GTK_MENU_ACCESSIBLE_H__

#include "gtkmenu.h"
#include "gtkmenushellaccessible.h"

G_BEGIN_DECLS

#define GTK_TYPE_MENU_ACCESSIBLE                          (_gtk_menu_accessible_get_type ())
#define GTK_MENU_ACCESSIBLE(obj)                          (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_MENU_ACCESSIBLE, GtkMenuAccessible))
#define GTK_MENU_ACCESSIBLE_CLASS(klass)                  (G_TYPE_CHECK_CLASS_CAST ((klass), GTK_TYPE_MENU_ACCESSIBLE, GtkMenuAccessibleClass))
#define GTK_IS_MENU_ACCESSIBLE(obj)                       (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_TYPE_MENU_ACCESSIBLE))
#define GTK_IS_MENU_ACCESSIBLE_CLASS(klass)               (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_MENU_ACCESSIBLE))
#define GTK_MENU_ACCESSIBLE_GET_CLASS(obj)                (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_MENU_ACCESSIBLE, GtkMenuAccessibleClass))

typedef struct _GtkMenuAccessible        GtkMenuAccessible;
typedef struct _GtkMenuAccessibleClass   GtkMenuAccessibleClass;
typedef struct _GtkMenuAccessiblePrivate GtkMenuAccessiblePrivate;

struct _GtkMenuAccessible
{
  GtkMenuShellAccessible parent;

  GtkMenuAccessiblePrivate *priv;
};

struct _GtkMenuAccessibleClass
{
  GtkMenuShellAccessibleClass parent_class;
};

GType _gtk_menu_accessible_get_type (void);

G_END_DECLS

#endif /* __GTK_MENU_ACCESSIBLE_H__ */

==> gtk+-3.9.0.tar.xz: gtk+-3.9.0/gtk/a11y/gtkmenuaccessible.h <==
/* GTK+ - accessibility implementations
 * Copyright 2001 Sun Microsystems Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __GTK_MENU_ACCESSIBLE_H__
#define __GTK_MENU_ACCESSIBLE_H__

#if !defined (__GTK_A11Y_H_INSIDE__) && !defined (GTK_COMPILATION)
#error "Only <gtk/gtk-a11y.h> can be included directly."
#endif

#include <gtk/gtk.h>
#include <gtk/a11y/gtkmenushellaccessible.h>

G_BEGIN_DECLS

#define GTK_TYPE_MENU_ACCESSIBLE                          (gtk_menu_accessible_get_type ())
#define GTK_MENU_ACCESSIBLE(obj)                          (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_MENU_ACCESSIBLE, GtkMenuAccessible))
#define GTK_MENU_ACCESSIBLE_CLASS(klass)                  (G_TYPE_CHECK_CLASS_CAST ((klass), GTK_TYPE_MENU_ACCESSIBLE, GtkMenuAccessibleClass))
#define GTK_IS_MENU_ACCESSIBLE(obj)                       (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_TYPE_MENU_ACCESSIBLE))
#define GTK_IS_MENU_ACCESSIBLE_CLASS(klass)               (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_MENU_ACCESSIBLE))
#define GTK_MENU_ACCESSIBLE_GET_CLASS(obj)                (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_MENU_ACCESSIBLE, GtkMenuAccessibleClass))

typedef struct _GtkMenuAccessible        GtkMenuAccessible;
typedef struct _GtkMenuAccessibleClass   GtkMenuAccessibleClass;
typedef struct _GtkMenuAccessiblePrivate GtkMenuAccessiblePrivate;

struct _GtkMenuAccessible
{
  GtkMenuShellAccessible parent;

  GtkMenuAccessiblePrivate *priv;
};

struct _GtkMenuAccessibleClass
{
  GtkMenuShellAccessibleClass parent_class;
};

GType gtk_menu_accessible_get_type (void);

G_END_DECLS

#endif /* __GTK_MENU_ACCESSIBLE_H__ */
